=========
Tutorials
=========

.. toctree::

   notebooks/BasisSet_tutorial.ipynb
   notebooks/BasisOpt_tutorial.ipynb
   notebooks/Molpro_tutorial.ipynb
   notebooks/GamessUS_tutorial.ipynb


Jupyter Notebooks
=================

The tutorials are also avaiable as `Jupyter <https://jupyter.org/>`_
notebooks:

- `BasisSet <http://nbviewer.jupyter.org/urls/bitbucket.org/lukaszmentel/chemtools/raw/tip//doc/source/notebooks/BasisSet_tutorial.ipynb>`_
- `Basis set optimization <http://nbviewer.jupyter.org/urls/bitbucket.org/lukaszmentel/chemtools/raw/tip//doc/source/notebooks/BasisOpt_tutorial.ipynb>`_
- `Gamess(US) wrapper <http://nbviewer.jupyter.org/urls/bitbucket.org/lukaszmentel/chemtools/raw/tip//doc/source/notebooks/GamessUS_tutorial.ipynb>`_
- `Molpro wrapper <http://nbviewer.jupyter.org/urls/itbucket.org/lukaszmentel/chemtools/raw/tip//doc/source/notebooks/Molpro_tutorial.ipynb>`_



